@@ -312,8 +312,18 @@ class Cli:
         translate(subtitles_file=srt_name)
 
     @staticmethod
-    def latexocr():
-        os.system("latexocr")
+    def ocr_server():
+        os.system("python -m sparrow.mllm.ocr")
+
+    @staticmethod
+    def ocr():
+        from sparrow import relp
+        os.system(f"streamlit run {relp('./mllm/ocr_web.py')} --server.port 27080")
+
+    @staticmethod
+    def prompt():
+        from sparrow import relp
+        os.system(f"streamlit run {relp('./prompts/demo.py')} --server.port 27081 --server.maxUploadSize=1000")
 
     @staticmethod
     def test_torch():
