@@ -10,6 +10,7 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from pandas import DataFrame
 
+
 def truncate_labels(labels, max_length=50):
     """截断长标签，确保每个标签的长度不超过max_length"""
     truncated_labels = []
@@ -21,13 +22,18 @@ def truncate_labels(labels, max_length=50):
         truncated_labels.append(truncated_label)
     return truncated_labels
 
+
 class MetricsCalculator:
     def __init__(self, df: "DataFrame", pred_col: str = 'predict', label_col: str = 'label',
-                 include_macro_micro_avg=False):
+                 include_macro_micro_avg=False,
+                 remove_matrix_zero_row=False,
+                 ):
         self.df = df
         self.y_pred = df[pred_col]
         self.y_true = df[label_col]
         self.all_labels = sorted(list(set(self.y_true.unique()).union(set(self.y_pred.unique()))))
+        self.needed_labels = None
+        self.remove_matrix_zero_row = remove_matrix_zero_row
         self.include_macro_micro_avg = include_macro_micro_avg
         self.metrics = self._calculate_metrics()
 
@@ -40,7 +46,6 @@ class MetricsCalculator:
         import warnings
         import warnings
 
-        
         # 全局设置默认字体，避免警告
         matplotlib.rcParams['font.sans-serif'] = ['SimHei']  # 设置中文字体
         matplotlib.rcParams['axes.unicode_minus'] = False  # 解决负号显示问题
@@ -69,7 +74,7 @@ class MetricsCalculator:
         # 忽略所有 UserWarning
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore", category=UserWarning)
-            
+
             # 绘制热力图
             sns.heatmap(conf_matrix, annot=True, fmt="d", cmap="Blues", xticklabels=all_labels,
                         yticklabels=all_labels)
@@ -107,12 +112,23 @@ class MetricsCalculator:
         # 计算每个类别的精确率、召回率、F1分数等
         report = classification_report(self.y_true, self.y_pred, labels=self.all_labels, output_dict=True,
                                        zero_division=0)
-
         # 移除宏平均和微平均，默认只保留加权平均
         if not self.include_macro_micro_avg:
             report = {label: metrics for label, metrics in report.items() if
                       label in self.all_labels or label == 'weighted avg'}
 
+        # 从report中移除不需要的类别，具体来说，去除support为0的类别
+        report = {label: metrics for label, metrics in report.items()
+                  if metrics['support'] > 0}
+
+        self.needed_labels = [label for label in report.keys() if label in self.all_labels]
+
+        # 移除matrix中不需要的行
+        needed_idx_list = [self.all_labels.index(label) for label in self.needed_labels]
+
+        if self.remove_matrix_zero_row:
+            conf_matrix = conf_matrix[needed_idx_list]
+
         # 返回结果
         return {
             'accuracy': accuracy,
@@ -143,7 +159,11 @@ class MetricsCalculator:
         separator = "|---" + "|---" * len(labels) + "|\n"
         rows = []
         for i, row in enumerate(matrix):
-            rows.append(f"| {labels[i]} | " + " | ".join(map(str, row)) + " |")
+            if self.remove_matrix_zero_row:
+                rows.append(f"| {self.needed_labels[i]} | " + " | ".join(map(str, row)) + " |")
+            else:
+                rows.append(f"| {labels[i]} | " + " | ".join(map(str, row)) + " |")
+
         return header + separator + "\n".join(rows)
 
 
@@ -157,11 +177,11 @@ def save_pred_metrics(df: "DataFrame", pred_col: str, label_col: str,
 
     table = [["指标概览", "Accuracy", "Precision", "Recall"],
              ["值", metrics['accuracy'], metrics['precision'], metrics['recall']]]
-    md = tabulate(table, headers="firstrow", tablefmt="github")
+    md = f"\n\n### 指标概览\n\n{tabulate(table, headers='firstrow', tablefmt='github')}"
     metrics_md = metrics_calculator.format_classification_report_as_markdown()
     confusion_matrix_md = metrics_calculator.format_confusion_matrix_as_markdown()
-    md += (f"\n### Classification Report\n{metrics_md}\n"
-           f"\n{confusion_matrix_md}")
+    md += (f"\n\n### Classification Report\n{metrics_md}\n"
+           f"\n### Confusion Matrix\n{confusion_matrix_md}")
     now = datetime.now().strftime("%m月%d日%H时%M分%S秒")
     record_folder = Path(record_folder)
     record_folder = record_folder / f'记录时间-{now}'
@@ -205,13 +225,14 @@ if __name__ == "__main__":
 
     # 示例使用
     data = {
-        'predict': ['cat', 'dog', 'cat', 'cat', 'dog', 'bird'],
+        'predict': ['cat', 'dog', 'cbbb', 'cat', 'dog', 'bird'],
         'label': ['cat', 'dog', 'dog', 'cat', 'dog', 'cat']
     }
     df = pd.DataFrame(data)
 
     metrics_calculator = MetricsCalculator(df)
     metrics = metrics_calculator.get_metrics()
+    print(metrics)
 
     print("Accuracy:", metrics['accuracy'])
     print("Precision:", metrics['precision'])
