@@ -1,4 +1,5 @@
 import asyncio
+from asyncio import Queue
 import itertools
 
 import time
@@ -195,7 +196,7 @@ class ConcurrentRequester:
 
             if len(batch) >= batch_size or (is_final and batch):
                 if is_final and progress:
-                    progress.print_summary()
+                    progress.summary()
                 yield StreamingResult(
                     completed_requests=sorted(batch, key=lambda x: x.request_id),
                     progress=progress,
@@ -226,15 +227,16 @@ class ConcurrentRequester:
             async for result in handle_completed_tasks(done, completed_batch, is_final=True):
                 yield result
 
-    async def stream_requests(
+    async def _stream_requests(
             self,
+            queue: Queue,
             request_params: Iterable[dict[str, Any]],
             url: str,
             method: str = 'POST',
             total_requests: Optional[int] = None,
             show_progress: bool = True,
             batch_size: int|None = None
-    ) -> AsyncIterator[StreamingResult]:
+    ) :
         """
         流式处理批量请求，实时返回已完成的结果
 
@@ -245,9 +247,6 @@ class ConcurrentRequester:
             total_requests: 总请求数量
             show_progress: 是否显示进度
             batch_size: 每次yield返回的最小完成请求数量
-
-        Yields:
-            StreamingResult: 包含已完成的请求结果和进度信息
         """
         progress = None
         if batch_size is None:
@@ -278,7 +277,36 @@ class ConcurrentRequester:
                     progress=progress,
                     batch_size=batch_size,
             ):
+                await queue.put(result)
+
+        await queue.put(None)
+
+    async def aiter_stream_requests(self,
+                                  request_params: Iterable[dict[str, Any]],
+                                  url: str,
+                                  method: str = 'POST',
+                                  total_requests: Optional[int] = None,
+                                  show_progress: bool = True,
+                                  batch_size: int | None = None
+                                  ):
+        queue = Queue()
+        task = asyncio.create_task(self._stream_requests(queue,
+                                                         request_params=request_params,
+                                                         url=url,
+                                                         method=method,
+                                                         total_requests=total_requests,
+                                                         show_progress=show_progress,
+                                                         batch_size=batch_size))
+        try:
+            while True:
+                result = await queue.get()
+                if result is None:
+                    break
                 yield result
+        finally:
+            if not task.done():
+                task.cancel()
+
 
     async def process_requests(
             self,
