@@ -2,6 +2,9 @@ import streamlit as st
 from manager import PromptManager
 from openai import OpenAI
 from streamlit_ace import st_ace
+from PIL import Image
+from sparrow.prompts.batch_predict import render_batch_testing
+import ast
 
 
 def init_session_state():  # noqa: ANN201
@@ -9,37 +12,73 @@ def init_session_state():  # noqa: ANN201
     if "show_delete_confirm" not in st.session_state:
         st.session_state.show_delete_confirm = False
         st.session_state.version_to_delete = None
+        st.session_state.input_var = "{user_input}"
 
-        oai_client = OpenAI(
-            # base_url="http://localhost:9999/v1", 
-            base_url="http://localhost:11434/v1",
-            api_key="empty",
+        st.session_state.model_config = {
+            "api_key": "empty",
+            # "base_url": "http://localhost:9999/v1",
+            "base_url": "http://localhost:11434/v1",
+            "model": "qwen2.5:latest",
+            "temperature": 0.7,
+            "top_p": 0.9,
+            "max_tokens": 256,
+            # "frequency_penalty": 0,
+            # "presence_penalty": 0,
+            # "stop": ["\n"],
+        }
+
+        st.session_state.oai_client = OpenAI(
+            api_key=st.session_state.model_config["api_key"],
+            base_url=st.session_state.model_config["base_url"]
         )
-        st.session_state.oai_client = oai_client
-        st.session_state.model = "qwen2.5"
 
         st.session_state.messages = [
             {"role": "system", "content": "你是一个有用的助手。"},
-            {"role": "user", "content": "{user_input}"},
+            {"role": "user", "content": f"{st.session_state.input_var}"},
         ]
 
 
 def set_model():
-    st.text_area("base_url", st.session_state.oai_client.base_url, key="base_url")
-    st.text_area("api_key", st.session_state.oai_client.api_key, key="api_key")
+    python_code = f"""\
+# ollama: http://localhost:11434/v1
+# sglang/vllm: http://localhost:9999/v1
+base_url = "{st.session_state.model_config["base_url"]}" 
+api_key = "{st.session_state.model_config["api_key"]}"
+"""
+    # code_response = st_ace(
+    #     value=python_code,
+    #     language="python",
+    #     # theme="monokai",
+    #     height=100,
+    #     key="code_response",
+    # )
+    # local_scope = {}
+    # exec(code_response, {}, local_scope)
+    # base_url = local_scope["base_url"]
+    # api_key = local_scope["api_key"]
+
+    st.text_input("base_url", st.session_state.model_config["base_url"], key="base_url")
+    st.text_input("api_key", st.session_state.model_config["api_key"], key="api_key")
+    base_url, api_key = st.session_state.base_url, st.session_state.api_key
+
+    st.session_state.oai_client.base_url = base_url
+    st.session_state.oai_client.api_key = api_key
+    st.session_state.model_config["base_url"] = base_url
+    st.session_state.model_config["api_key"] = api_key
+
     model_list = st.session_state.oai_client.models.list()
     model_name_list = [i.id for i in model_list.data]
-    print(f"{model_list=}")
-    # print(f"{model_name_list=}")
-    st.selectbox("model_name", model_name_list, key="model_name")
-    st.session_state.oai_client.base_url = st.session_state[f"base_url"]
-    st.session_state.oai_client.api_key = st.session_state[f"api_key"]
-    st.session_state.model = st.session_state[f"model_name"]
+
+    st.selectbox("model_name",
+                 model_name_list,
+                 index=model_name_list.index(st.session_state.model_config["model"]) if st.session_state.model_config["model"] in model_name_list else 0,
+                 key="model_name")
+    st.session_state.model_config["model"] = st.session_state[f"model_name"]
 
 
 def add_message(multimodal=False):
     if multimodal:
-        st.session_state.messages.append({"role": "mm_user",
+        st.session_state.messages.append({"role": "user",
                                           "content": [
                                               {"type": "text", "text": "", },
                                               {"type": "image_url",
@@ -78,7 +117,7 @@ def update_multimodal_message_content(index, content_type, inner_index):
 
 @st.fragment
 def add_one_multimodal_message(message, i):
-    ROLES = ["user", "assistant", "mm_user"]
+    ROLES = ["user", "assistant"]
     cols = st.columns([0.2, 0.70, 0.1])
 
     with cols[0]:
@@ -91,10 +130,10 @@ def add_one_multimodal_message(message, i):
         st.session_state.messages[i]["role"] = role
 
     with cols[1]:
-        if role == "mm_user":
+        if role == "user":
             if isinstance(message['content'], str):
                 message['content'] = [
-                    {"type": "text", "text": ""},
+                    {"type": "text", "text": f"{st.session_state.input_var}"},
                     {"type": "image_url",
                      "image_url": "https://"}
                 ]
@@ -190,7 +229,7 @@ def render_prompt_creation(pm):
                 new_prompt_name = st.text_input("新建 Prompt 名称")
                 messages = [
                     {"role": "system", "content": "你是一个有用的助手。"},
-                    {"role": "user", "content": "{user_input}"},
+                    {"role": "user", "content": f"{st.session_state.input_var}"},
                 ]
                 current_prompt_name = new_prompt_name
             else:
@@ -432,7 +471,7 @@ def render_ai_response(messages: list[dict], append_to_history=False):
         full_response = ""
         client: OpenAI = st.session_state.oai_client
         for response in client.chat.completions.create(
-                model=st.session_state.model,
+                model=st.session_state.model_config["model"],
                 messages=messages,
                 stream=True,
         ):
@@ -443,23 +482,32 @@ def render_ai_response(messages: list[dict], append_to_history=False):
             st.session_state.messages.append({"role": "assistant", "content": full_response})
 
 
-def render_ai_history():
+def render_ai_history(is_multimodal: bool):
     for message in st.session_state.messages:
         with st.chat_message(message["role"]):
-            st.write(message["content"])
+            content = message["content"]
+            if isinstance(content, list):
+                for i in message["content"]:
+                    if "text" in i:
+                        st.write(i['text'])
+                    elif "image_url" in i:
+                        try:
+                            st.image(i['image_url'])
+                        except:
+                            pass
+            else:
+                st.write(message["content"])
 
 
 def render_debug_section(is_multimodal: bool):
     """Render debug section"""
     st.header("Prompt 调试区")
     _the_last_msg = st.session_state.messages[-1]
-    print(f"{_the_last_msg=}")
 
-    input_var = "user_input"
-
-    prompt_str = f"{{{input_var}}}"
+    prompt_str = st.session_state.input_var
 
     def add_content_to_msg(content):
+        nonlocal is_multimodal
         if not is_multimodal:
             st.session_state.messages.append({
                 "role": "user",
@@ -473,42 +521,51 @@ def render_debug_section(is_multimodal: bool):
                 ]
             })
 
-    if _the_last_msg['role'] not in ('user', 'mm_user'):
-        add_content_to_msg(prompt_str)
-
-
     def get_prompt_str(content):
-        prompt_str = f"{{{input_var}}}"
+        nonlocal prompt_str
         if isinstance(content, str):
-            if input_var in content:
+            if st.session_state.input_var in content:
                 prompt_str = content
         elif isinstance(content, list):
             for i in content:
                 if i['type'] == 'text':
-                    if input_var in i['text']:
+                    if st.session_state.input_var in i['text']:
                         prompt_str = i['text']
         else:
             raise
         return prompt_str
 
-    the_last_msg = st.session_state.messages.pop()
-    if st.toggle("追加至prompt历史", value=False):
-        if prompt := st.chat_input("测试输入"):
-            prompt_str = get_prompt_str(the_last_msg['content'])
-            render_ai_history()
-            with st.chat_message("user"):
-                content = prompt_str.format(**{input_var: prompt})
-                st.write(content)
-            add_content_to_msg(content)
-            render_ai_response(st.session_state.messages, append_to_history=True)
-    elif prompt := st.chat_input("测试输入"):
+    if _the_last_msg['role'] not in ('user',):
+        add_content_to_msg(prompt_str)
+
+    append_to_history = st.toggle("追加至prompt历史", value=False)
+
+    if prompt_input := st.chat_input("测试输入", accept_file="multiple"):
+        prompt = prompt_input.text
+        pil_image_list = []
+        image_file_list = []
+
+        for file in prompt_input.files:
+            # 如果file类型是图片，则用pillow加载
+            if file.type.startswith("image/"):
+                pil_image_list.append(Image.open(file))
+                image_file_list.append(file.name)
+
+        the_last_msg = st.session_state.messages.pop()
         prompt_str = get_prompt_str(the_last_msg['content'])
-        render_ai_history()
+        render_ai_history(is_multimodal=is_multimodal)
         with st.chat_message("user"):
-            content = prompt_str.format(**{input_var: prompt})
+            content = prompt_str.format(**{st.session_state.input_var[1:-1]: prompt})
+            if pil_image_list:
+                # 将图片显示在同一行：
+                with st.container():
+                    cols = st.columns(len(pil_image_list))
+                    for col, pil_image in zip(cols, pil_image_list):
+                        with col:
+                            st.image(pil_image)
             st.write(content)
         add_content_to_msg(content)
-        render_ai_response(st.session_state.messages, append_to_history=False)
+        render_ai_response(st.session_state.messages, append_to_history=append_to_history)
 
 
 def main():
@@ -525,6 +582,8 @@ def main():
         render_debug_section(is_multimodal_prompt)
     elif mode == "加载已有 Prompt":
         render_prompt_loading(pm)
+    elif mode == "批量测试":
+        render_batch_testing(pm)
     else:
         st.header("敬请期待")
         st.write("todo")
